
#ifndef AD_H
#define AD_H

/*
 * interface to D/A converter
 *
 * - after DA_wakeup(), energy is consumed until DA_sleep()
 * - measurements can only be taken if D/A is awake
 * - DA_sample() initiates a measurement, it may take an arbitrary amount of
 *   time until the measurement is done
 * - DA_ready() indicates whether a measured value is available
 * - DA_get_value() retrieves the value from the last measurement, if a
 *   value has been retrieved once, the D/A device may internally discard the
 *   value
 * - measurements are subject to some noise, the measurement gets more precise
 *   with multiple measurements in a row: the average of at least two
 *   measurements in a row, i.e. without setting the converter to sleep in
 *   between, is guaranteed to be sufficiently precise
 */

// 0: D/A ready to sample
//
extern int DA_wakeup();

// -1: D/A not operational
//  0: measurement has been initiated
//
extern int DA_sample();

// -1: DA not operational
//  0: DA operational but value not yet ready
//  1: value ready 
//
extern int DA_ready();

//           -1: no value available
// 0..SHORT_MAX: value from last measurement
//
extern int DA_get_value();

// 0: D/A set to sleep mode; if not sleeping now, it's woken up first (which
//    consumes precious energy)
//
extern int DA_sleep();

#endif
